@@ -31,7 +31,7 @@
 #endif
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "../rrd_config.h"
 #endif
 
 #if !defined (__STDC__) || !__STDC__
