@@ -32,6 +32,9 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+/* NOTE: nothing in here is thread-safe!!!! Not even the localtime
+   calls ... */
+
 /*
  * The BNF-like specification of the time syntax parsed is below:
  *                                                               
@@ -231,25 +234,24 @@ static struct SpecialToken TimeMultipliers[] = {
  */
 static struct SpecialToken *Specials;
 
-static char **scp;	/* scanner - pointer at arglist */
+static const char **scp;	/* scanner - pointer at arglist */
 static char scc;	/* scanner - count of remaining arguments */
-static char *sct;	/* scanner - next char pointer in current argument */
+static const char *sct;	/* scanner - next char pointer in current argument */
 static int need;	/* scanner - need to advance to next argument */
 
 static char *sc_token=NULL;	/* scanner - token buffer */
 static size_t sc_len;   /* scanner - length of token buffer */
 static int sc_tokid;	/* scanner - token id */
 
-static int need_to_free = 0; /* means that we need deallocating memory */
-
 /* Local functions */
+static void EnsureMemFree (void);
 
-void EnsureMemFree ()
+static void EnsureMemFree (void)
 {
-  if( need_to_free )
+  if( sc_token )
     {
     free(sc_token);
-    need_to_free = 0;
+    sc_token = NULL;
     }
 }
 
@@ -365,7 +367,7 @@ parse_token(char *arg)
  * init_scanner() sets up the scanner to eat arguments
  */
 static char *
-init_scanner(int argc, char **argv)
+init_scanner(int argc, const char **argv)
 {
     scp = argv;
     scc = argc;
@@ -377,7 +379,6 @@ init_scanner(int argc, char **argv)
     sc_token = (char *) malloc(sc_len*sizeof(char));
     if( sc_token == NULL )
       return "Failed to allocate memory";
-    need_to_free = 1;
     return TIME_OK;
 } /* init_scanner */
 
@@ -556,10 +557,9 @@ tod(struct rrd_time_value *ptv)
 {
     int hour, minute = 0;
     int tlen;
-    
     /* save token status in  case we must abort */
     int scc_sv = scc; 
-    char *sct_sv = sct; 
+    const char *sct_sv = sct; 
     int sc_tokid_sv = sc_tokid;
 
     tlen = strlen(sc_token);
@@ -582,7 +582,7 @@ tod(struct rrd_time_value *ptv)
       return TIME_OK;
     }
     if (sc_tokid == COLON ) {
-       try(expect2(NUMBER,
+	try(expect2(NUMBER,
             "Parsing HH:MM syntax, expecting MM as number, got none"));
 	minute = atoi(sc_token);
 	if (minute > 59) {
@@ -659,9 +659,9 @@ assign_date(struct rrd_time_value *ptv, long mday, long mon, long year)
 static char *
 day(struct rrd_time_value *ptv)
 {
-    long mday=0, wday, mon, year = ptv->tm.tm_year;
+    /* using time_t seems to help portability with 64bit oses */    
+    time_t mday=0, wday, mon, year = ptv->tm.tm_year;
     int tlen;
-    time_t montime;
 
     switch (sc_tokid) {
     case YESTERDAY:
@@ -680,7 +680,7 @@ day(struct rrd_time_value *ptv)
 	    /* do month mday [year]
 	     */
 	    mon = (sc_tokid-JAN);
-           try(expect2(NUMBER,
+	    try(expect2(NUMBER,
 		"the day of the month should follow month name"));
 	    mday = atol(sc_token);
 	    if (token() == NUMBER) {
@@ -699,6 +699,7 @@ day(struct rrd_time_value *ptv)
 	     */
 	    wday = (sc_tokid-SUN);
 	    ptv->tm.tm_mday += (wday - ptv->tm.tm_wday);
+            token();
 	    break;
 	    /*
 	    mday = ptv->tm.tm_mday;
@@ -715,8 +716,7 @@ day(struct rrd_time_value *ptv)
 	    tlen = strlen(sc_token);
 	    mon = atol(sc_token);
             if (mon > 10*365*24*60*60) {
-                montime = mon;
-                ptv->tm=*localtime(&montime);
+		ptv->tm=*localtime(&mon);
 		token();
 		break;
 	    }
@@ -736,11 +736,11 @@ day(struct rrd_time_value *ptv)
 	      if (mon <= 31 && (sc_tokid == SLASH || sc_tokid == DOT)) {
 		int sep;		    
 		sep = sc_tokid;
-               try(expect2(NUMBER,"there should be %s number after '%c'",
+		try(expect2(NUMBER,"there should be %s number after '%c'",
 			   sep == DOT ? "month" : "day", sep == DOT ? '.' : '/'));
 		mday = atol(sc_token);
 		if (token() == sep) {
-                 try(expect2(NUMBER,"there should be year number after '%c'",
+		  try(expect2(NUMBER,"there should be year number after '%c'",
 			     sep == DOT ? '.' : '/'));
 		  year = atol(sc_token);
 		  token();
@@ -784,7 +784,7 @@ day(struct rrd_time_value *ptv)
  * the pointer to the error message in the case of problems
  */
 char *
-parsetime(char *tspec, struct rrd_time_value *ptv)
+parsetime(const char *tspec, struct rrd_time_value *ptv)
 {
     time_t now = time(NULL);
     int hr = 0;
@@ -798,8 +798,7 @@ parsetime(char *tspec, struct rrd_time_value *ptv)
     ptv->type = ABSOLUTE_TIME;
     ptv->offset = 0;
     ptv->tm = *localtime(&now);
-    /* local time has set this right */
-/*    ptv->tm.tm_isdst = -1; -- mk time can figure this out for us ... */
+    ptv->tm.tm_isdst = -1; /* mk time can figure this out for us ... */
 
     token();
     switch (sc_tokid) {
@@ -838,8 +837,24 @@ parsetime(char *tspec, struct rrd_time_value *ptv)
 
     /* Only absolute time specifications below */
     case NUMBER:
-	    try(tod(ptv))
-	    if (sc_tokid != NUMBER) break; 
+	    {
+	      long hour_sv = ptv->tm.tm_hour;
+	      long year_sv = ptv->tm.tm_year;
+              ptv->tm.tm_hour = 30;
+              ptv->tm.tm_year = 30000;
+  	      try(tod(ptv))
+      	      try(day(ptv))
+	      if ( ptv->tm.tm_hour == 30 &&  ptv->tm.tm_year != 30000 ){
+		try(tod(ptv))
+              }
+	      if ( ptv->tm.tm_hour == 30 ){
+		ptv->tm.tm_hour = hour_sv;
+              }
+	      if ( ptv->tm.tm_hour == 30000 ){
+		ptv->tm.tm_year = year_sv;
+              }
+	    };	    
+            break;
     /* fix month parsing */
     case JAN: case FEB: case MAR: case APR: case MAY: case JUN:
     case JUL: case AUG: case SEP: case OCT: case NOV: case DEC:
@@ -900,7 +915,7 @@ parsetime(char *tspec, struct rrd_time_value *ptv)
       panic(e("unparsable trailing text: '...%s%s'", sc_token, sct));
     }
 
-    /*    ptv->tm.tm_isdst = -1; */ /* for mktime to guess DST status */
+    ptv->tm.tm_isdst = -1; /* for mktime to guess DST status */
     if( ptv->type == ABSOLUTE_TIME )
       if( mktime( &ptv->tm ) == -1 ) { /* normalize & check */
         /* can happen for "nonexistent" times, e.g. around 3am */
