@@ -1,9 +1,9 @@
 /*****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
  *****************************************************************************
  * rrd_dump  Display a RRD
  *****************************************************************************
- * $Id: rrd_dump.c 860 2006-07-14 12:11:16Z oetiker $
+ * $Id: rrd_dump.c 986 2007-02-01 05:51:34Z oetiker $
  * $Log$
  * Revision 1.7  2004/05/25 20:53:21  oetiker
  * prevent small leak when resources are exhausted -- Mike Slifcak
@@ -44,7 +44,7 @@
 #include "rrd_tool.h"
 #include "rrd_rpncalc.h"
 
-#ifndef NETWARE
+#if !(defined(NETWARE) || defined(WIN32))
 extern char *tzname[2];
 #endif
 
