@@ -1,9 +1,9 @@
 /*****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
  *****************************************************************************
  * rrd_error.c   Common Header File
  *****************************************************************************
- * $Id: rrd_error.c 860 2006-07-14 12:11:16Z oetiker $
+ * $Id: rrd_error.c 986 2007-02-01 05:51:34Z oetiker $
  * $Log$
  * Revision 1.4  2003/02/22 21:57:03  oetiker
  * a patch to avoid a memory leak and a Makefile.am patch to
@@ -80,6 +80,7 @@ rrd_set_error_r(struct rrd_context *rrd_ctx, char *fmt, ...)
     va_start(argp, fmt);
 #ifdef HAVE_VSNPRINTF
     vsnprintf((char *)rrd_ctx->rrd_error, rrd_ctx->len, fmt, argp);
+    rrd_ctx->rrd_error[rrd_ctx->len]='\0';
 #else
     vsprintf((char *)rrd_ctx->rrd_error, fmt, argp);
 #endif
@@ -110,7 +111,6 @@ rrd_new_context(void) {
 	(struct rrd_context *) malloc(sizeof(struct rrd_context));
 
     if (rrd_ctx) {
-	rrd_ctx->len = 0;
 	rrd_ctx->rrd_error = malloc(MAXLEN+10);
 	rrd_ctx->lib_errstr = malloc(ERRBUFLEN+10);
 	if (rrd_ctx->rrd_error && rrd_ctx->lib_errstr) {
