@@ -1,5 +1,5 @@
 /****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
  ****************************************************************************
  * rrd_graph_helper.c  commandline parser functions 
  *                     this code initially written by Alex van den Bogaerdt
@@ -133,6 +133,10 @@ rrd_parse_find_gf(const char *const line, unsigned int *const eaten, graph_desc_
 	    rrd_set_error("Malformed '%s' command in line '%s'\n",&line[*eaten],line);
 	    return 1;
     }
+    if (line[*eaten] == '\0') {
+       rrd_set_error("Expected some arguments after '%s'\n",line);
+       return 1;
+    }
     return 0;
 }
 
@@ -629,7 +633,7 @@ rrd_parse_def(const char *const line, unsigned int *const eaten, graph_desc_t *c
     dprintf("- from line '%s'\n",line);
 
     if (rrd_parse_make_vname(line,eaten,gdp,im)) return 1;
-    i=scan_for_col(&line[*eaten],254,gdp->rrd);
+    i=scan_for_col(&line[*eaten],sizeof(gdp->rrd)-1,gdp->rrd);
     if (line[*eaten+i]!=':') {
 	rrd_set_error("Problems reading database name");
 	return 1;
