@@ -1,5 +1,5 @@
 /****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
  ****************************************************************************
  * rrd_rpncalc.c  RPN calculator functions
  ****************************************************************************/
@@ -760,7 +760,7 @@ rpn_calc(rpnp_t *rpnp, rpnstack_t *rpnstack, long data_idx,
            case OP_AVG:
                stackunderflow(0);
                 {
-                   int i=rpnstack -> s[stptr--];
+                   int i=(int)rpnstack -> s[stptr--];
                    double sum=0;
                    int count=0;
                    stackunderflow(i-1);
