@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
  *****************************************************************************
  * rrd_tool.c  Startup wrapper
  *****************************************************************************/
@@ -22,13 +22,14 @@ void PrintUsage(char *cmd)
 {
 
     char help_main[] =
-	   "RRDtool " PACKAGE_VERSION "  Copyright 1997-2006 by Tobias Oetiker <tobi@oetiker.ch>\n"
+	   "RRDtool " PACKAGE_VERSION "  Copyright 1997-2007 by Tobias Oetiker <tobi@oetiker.ch>\n"
            "               Compiled " __DATE__ " " __TIME__ "\n\n"
 	   "Usage: rrdtool [options] command command_options\n\n";
 
     char help_list[] =
 	   "Valid commands: create, update, updatev, graph, dump, restore,\n"
-	   "\t\tlast, first, info, fetch, tune, resize, xport\n\n";
+	   "\t\tlast, lastupdate, first, info, fetch, tune,\n"
+	   " resize, xport\n\n";
 
     char help_listremote[] =
            "Valid remote commands: quit, ls, cd, mkdir, pwd\n\n";
@@ -57,6 +58,11 @@ void PrintUsage(char *cmd)
            "* last - show last update time for RRD\n\n"
            "\trrdtool last filename.rrd\n\n";
 
+    char help_lastupdate[] =
+          "* lastupdate - returns the most recent datum stored for\n"
+          "  each DS in an RRD\n\n"
+          "\trrdtool lastupdate filename.rrd\n\n"; 
+
     char help_first[] =
            "* first - show first update time for RRA within an RRD\n\n"
            "\trrdtool first filename.rrd [--rraindex number]\n\n";
@@ -159,6 +165,7 @@ void PrintUsage(char *cmd)
 	   "\trrdtool xport [-s|--start seconds] [-e|--end seconds]\n"
 	   "\t\t[-m|--maxrows rows]\n"
 	   "\t\t[--step seconds]\n"	   
+	   "\t\t[--enumds]\n"	   
 	   "\t\t[DEF:vname=rrd:ds-name:CF]\n"
 	   "\t\t[CDEF:vname=rpn-expression]\n"
            "\t\t[XPORT:vname:legend]\n\n";
@@ -189,9 +196,10 @@ void PrintUsage(char *cmd)
 
 	   "For more information read the RRD manpages\n\n";
 
-    enum { C_NONE, C_CREATE, C_DUMP, C_INFO, C_RESTORE, C_LAST, C_FIRST,
-	   C_UPDATE, C_FETCH, C_GRAPH, C_TUNE, C_RESIZE, C_XPORT,
-           C_QUIT, C_LS, C_CD, C_MKDIR, C_PWD, C_UPDATEV };
+    enum { C_NONE, C_CREATE, C_DUMP, C_INFO, C_RESTORE, C_LAST,
+    	   C_LASTUPDATE, C_FIRST, C_UPDATE, C_FETCH, C_GRAPH, C_TUNE,
+	   C_RESIZE, C_XPORT, C_QUIT, C_LS, C_CD, C_MKDIR, C_PWD,
+	   C_UPDATEV };
 
     int help_cmd = C_NONE;
 
@@ -207,6 +215,8 @@ void PrintUsage(char *cmd)
 		help_cmd = C_RESTORE;
     	    else if (!strcmp(cmd,"last"))
 		help_cmd = C_LAST;
+    	    else if (!strcmp(cmd,"lastupdate"))
+		help_cmd = C_LASTUPDATE;
     	    else if (!strcmp(cmd,"first"))
 		help_cmd = C_FIRST;
     	    else if (!strcmp(cmd,"update"))
@@ -258,6 +268,9 @@ void PrintUsage(char *cmd)
 	    case C_LAST:
 		fputs(help_last, stdout);
 		break;
+	    case C_LASTUPDATE:
+		fputs(help_lastupdate, stdout);
+		break;
 	    case C_FIRST:
 		fputs(help_first, stdout);
 		break;
@@ -606,7 +619,7 @@ int HandleInputLine(int argc, char **argv, FILE* out)
 	}
 	free(data);
     }
-	
+
     else if (strcmp("--version", argv[1]) == 0 ||
 	     strcmp("version", argv[1]) == 0 || 
 	     strcmp("v", argv[1]) == 0 ||
@@ -620,7 +633,28 @@ int HandleInputLine(int argc, char **argv, FILE* out)
 	rrd_resize(argc-1, &argv[1]);
     else if (strcmp("last", argv[1]) == 0)
         printf("%ld\n",rrd_last(argc-1, &argv[1]));
-    else if (strcmp("first", argv[1]) == 0)
+    else if (strcmp("lastupdate", argv[1]) == 0) {
+	   time_t      last_update;
+           char        **ds_namv;
+           char        **last_ds;
+           unsigned long ds_cnt,
+                       i;
+          if (rrd_lastupdate(argc-1, &argv[1], &last_update,
+                       &ds_cnt, &ds_namv, &last_ds) == 0) {
+               for (i=0; i<ds_cnt; i++)
+                       printf(" %s", ds_namv[i]);
+               printf("\n\n");
+               printf("%10lu:", last_update);
+               for (i=0; i<ds_cnt; i++) {
+                       printf(" %s", last_ds[i]);
+                       free(last_ds[i]);
+                       free(ds_namv[i]);
+               }
+               printf("\n");
+               free(last_ds);
+               free(ds_namv);
+          }
+    } else if (strcmp("first", argv[1]) == 0)
         printf("%ld\n",rrd_first(argc-1, &argv[1]));
     else if (strcmp("update", argv[1]) == 0)
 	rrd_update(argc-1, &argv[1]);
@@ -647,13 +681,22 @@ int HandleInputLine(int argc, char **argv, FILE* out)
 	    free (data);
 	}
     } else if (strcmp("xport", argv[1]) == 0) {
-       int xxsize;
+        int xxsize;
 	unsigned long int j = 0;
 	time_t        start,end, ti;
 	unsigned long step, col_cnt,row_cnt;
 	rrd_value_t   *data,*ptr;
 	char          **legend_v;
-       if(rrd_xport(argc-1, &argv[1], &xxsize,&start,&end,&step,&col_cnt,&legend_v,&data) != -1) {
+        int           enumds = 0;
+        int           i;
+        char *vtag = NULL;
+        vtag = malloc( strlen(COL_DATA_TAG)+10);
+	for ( i = 2; i < argc; i++){
+		if (strcmp("--enumds", argv[i]) == 0)
+			enumds = 1;
+	}
+
+        if(rrd_xport(argc-1, &argv[1], &xxsize,&start,&end,&step,&col_cnt,&legend_v,&data) != -1) {
 	  row_cnt = (end-start)/step;
 	  ptr = data;
 	  printf("<?xml version=\"1.0\" encoding=\"%s\"?>\n\n", XML_ENCODING);
@@ -680,11 +723,16 @@ int HandleInputLine(int argc, char **argv, FILE* out)
 	    printf ("<%s>%lu</%s>", COL_TIME_TAG, ti, COL_TIME_TAG);
 	    for (j = 0; j < col_cnt; j++) {
 	      rrd_value_t newval = DNAN;
+              if (enumds == 1)
+		snprintf(vtag,sizeof(vtag),"%s%lu", COL_DATA_TAG, j);
+	      else
+		snprintf(vtag,sizeof(vtag),"%s",COL_DATA_TAG);
+              
 	      newval = *ptr;
 	      if(isnan(newval)){
-		printf("<%s>NaN</%s>", COL_DATA_TAG, COL_DATA_TAG);
+                printf("<%s>NaN</%s>", vtag,vtag);
 	      } else {
-		printf("<%s>%0.10e</%s>", COL_DATA_TAG, newval, COL_DATA_TAG);
+		printf("<%s>%0.10e</%s>", vtag, newval, vtag);
 	      };
 	      ptr++;
 	    }
@@ -694,6 +742,7 @@ int HandleInputLine(int argc, char **argv, FILE* out)
 	  printf("  </%s>\n", DATA_TAG);
 	  printf("</%s>\n", ROOT_TAG);
 	}
+        free(vtag);
     }
     else if (strcmp("graph", argv[1]) == 0) {
 	char **calcpr;
