@@ -1,9 +1,9 @@
 /*****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
  *****************************************************************************
  * rrd_update.c  RRD Update Function
  *****************************************************************************
- * $Id: rrd_update.c 860 2006-07-14 12:11:16Z oetiker $
+ * $Id: rrd_update.c 986 2007-02-01 05:51:34Z oetiker $
  *****************************************************************************/
 
 #include "rrd_tool.h"
@@ -94,31 +94,12 @@ int _rrd_update(char *filename, char *tmplt, int argc, char **argv,
 #define IFDNAN(X,Y) (isnan(X) ? (Y) : (X));
 
 
-#ifdef STANDALONE
-int 
-main(int argc, char **argv){
-        rrd_update(argc,argv);
-        if (rrd_test_error()) {
-                printf("RRDtool " PACKAGE_VERSION "  Copyright by Tobi Oetiker, 1997-2005\n\n"
-                        "Usage: rrdupdate filename\n"
-                        "\t\t\t[--template|-t ds-name:ds-name:...]\n"
-                        "\t\t\ttime|N:value[:value...]\n\n"
-                        "\t\t\tat-time@value[:value...]\n\n"
-                        "\t\t\t[ time:value[:value...] ..]\n\n");
-                                   
-                printf("ERROR: %s\n",rrd_get_error());
-                rrd_clear_error();                                                            
-                return 1;
-        }
-        return 0;
-}
-#endif
-
 info_t *rrd_update_v(int argc, char **argv)
 {
     char             *tmplt = NULL;          
 	info_t *result = NULL;
 	infoval rc;
+      rc.u_int = -1;
     optind = 0; opterr = 0;  /* initialize getopt */
 
     while (1) {
@@ -142,7 +123,6 @@ info_t *rrd_update_v(int argc, char **argv)
 		
 		case '?':
 			rrd_set_error("unknown option '%s'",argv[optind-1]);
-            rc.u_int = -1;
 			goto end_tag;
 		}
     }
@@ -150,9 +130,9 @@ info_t *rrd_update_v(int argc, char **argv)
     /* need at least 2 arguments: filename, data. */
     if (argc-optind < 2) {
 		rrd_set_error("Not enough arguments");
-        rc.u_int = -1;
 		goto end_tag;
     }
+    rc.u_int = 0;
     result = info_push(NULL,sprintf_alloc("return_value"),RD_I_INT,rc);
    	rc.u_int = _rrd_update(argv[optind], tmplt,
 		      argc - optind - 1, argv + optind + 1, result);
@@ -286,6 +266,7 @@ _rrd_update(char *filename, char *tmplt, int argc, char **argv,
     unsigned long    rrd_filesize;
 #endif
 
+
     rpnstack_init(&rpnstack);
 
     /* need at least 1 arguments: data. */
@@ -447,7 +428,7 @@ _rrd_update(char *filename, char *tmplt, int argc, char **argv,
 #endif
     /* loop through the arguments. */
     for(arg_i=0; arg_i<argc;arg_i++) {
-	char *stepper = malloc((strlen(argv[arg_i])+1)*sizeof(char));
+	char *stepper = strdup(argv[arg_i]);
         char *step_start = stepper;
 	char *p;
 	char *parsetime_error = NULL;
@@ -455,6 +436,7 @@ _rrd_update(char *filename, char *tmplt, int argc, char **argv,
 	struct rrd_time_value ds_tv;
         if (stepper == NULL){
                 rrd_set_error("failed duplication argv entry");
+		free(step_start);
                 free(updvals);
                 free(pdp_temp);  
                 free(tmpl_idx);
@@ -468,7 +450,6 @@ _rrd_update(char *filename, char *tmplt, int argc, char **argv,
 	/* initialize all ds input to unknown except the first one
            which has always got to be set */
 	for(ii=1;ii<=rrd.stat_head->ds_cnt;ii++) updvals[ii] = "U";
-	strcpy(stepper,argv[arg_i]);
 	updvals[0]=stepper;
 	/* separate all ds elements; first must be examined separately
 	   due to alternate time syntax */
@@ -481,7 +462,7 @@ _rrd_update(char *filename, char *tmplt, int argc, char **argv,
 	    *p = '\0';
 	    stepper = p+1;
 	} else {
-	    rrd_set_error("expected timestamp not found in data source from %s:...",
+	    rrd_set_error("expected timestamp not found in data source from %s",
 			  argv[arg_i]);
 	    free(step_start);
 	    break;
@@ -500,7 +481,7 @@ _rrd_update(char *filename, char *tmplt, int argc, char **argv,
 	}
 
 	if (ii != tmpl_cnt-1) {
-	    rrd_set_error("expected %lu data source readings (got %lu) from %s:...",
+	    rrd_set_error("expected %lu data source readings (got %lu) from %s",
 			  tmpl_cnt-1, ii, argv[arg_i]);
 	    free(step_start);
 	    break;
@@ -609,9 +590,9 @@ _rrd_update(char *filename, char *tmplt, int argc, char **argv,
 	    dst_idx= dst_conv(rrd.ds_def[i].dst);
 
             /* make sure we do not build diffs with old last_ds values */
-	    if(rrd.ds_def[i].par[DS_mrhb_cnt].u_cnt < interval 
-	    	&& ( dst_idx == DST_COUNTER || dst_idx == DST_DERIVE)){
+	    if(rrd.ds_def[i].par[DS_mrhb_cnt].u_cnt < interval) {
 		strncpy(rrd.pdp_prep[i].last_ds,"U",LAST_DS_LEN-1);
+		rrd.pdp_prep[i].last_ds[LAST_DS_LEN-1]='\0';
 	    }
 
   	    /* NOTE: DST_CDEF should never enter this if block, because
@@ -720,11 +701,8 @@ _rrd_update(char *filename, char *tmplt, int argc, char **argv,
 		    rrd.pdp_prep[i].last_ds,
 		    updvals[i+1], pdp_new[i]);
 #endif
-	    if(dst_idx == DST_COUNTER || dst_idx == DST_DERIVE){
-		strncpy(rrd.pdp_prep[i].last_ds,
-			updvals[i+1],LAST_DS_LEN-1);
-		rrd.pdp_prep[i].last_ds[LAST_DS_LEN-1]='\0';
-	    }
+	    strncpy(rrd.pdp_prep[i].last_ds, updvals[i+1],LAST_DS_LEN-1);
+	    rrd.pdp_prep[i].last_ds[LAST_DS_LEN-1]='\0';
 	}
 	/* break out of the argument parsing loop if the error_string is set */
 	if (rrd_test_error()){
