@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
  *****************************************************************************
  * rrd_version Return
  *****************************************************************************
@@ -14,4 +14,10 @@ rrd_version(void)
   return NUMVERS;
 }
 
+char *
+rrd_strversion(void)
+{
+  return PACKAGE_VERSION;
+}
+
 
