@@ -1,5 +1,5 @@
 /****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
  ****************************************************************************
  * rrd_xport.c  export RRD data 
  ****************************************************************************/
@@ -61,6 +61,7 @@ rrd_xport(int argc, char **argv, int UNUSED(*xsize),
 	    {"end",        required_argument, 0,  'e'},
 	    {"maxrows",    required_argument, 0,  'm'},
 	    {"step",       required_argument, 0,   261},
+	    {"enumds",     no_argument,       0,   262}, /* these are handled in the frontend ... */
 	    {0,0,0,0}
 	};
 	int option_index = 0;
@@ -76,6 +77,8 @@ rrd_xport(int argc, char **argv, int UNUSED(*xsize),
 	case 261:
 	    im.step =  atoi(optarg);
 	    break;
+	case 262:
+	    break;
 	case 's':
 	    if ((parsetime_error = parsetime(optarg, &start_tv))) {
 	        rrd_set_error( "start time: %s", parsetime_error );
@@ -96,7 +99,7 @@ rrd_xport(int argc, char **argv, int UNUSED(*xsize),
 	    }
 	    break;
 	case '?':
-	    rrd_set_error("unknown option '%c'", optopt);
+            rrd_set_error("unknown option '%s'",argv[optind-1]);
             return -1;
 	}
     }
